==> nextcloud-app-bookmarks-1%3a0.16.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/gl.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcadores",
    "Add a Bookmark" : "Engadir un marcador",
    "Add folder" : "Engadir cartafol",
    "Select" : "Seleccionar",
    "Deselect" : "Deseleccionar",
    "Details" : "Detalles",
    "Delete" : "Eliminar",
    "Saved" : "Gardado",
    "Date added" : "Data na que foi engadido",
    "Link" : "Ligazón",
    "Tags" : "Etiquetas",
    "Description" : "Descrición",
    "No bookmarks here." : "Aquí non hai marcadores. ",
    "Favorites" : "Favoritos",
    "Settings" : "Axustes",
    "Bookmarklet" : "Miniaplicativo ligado",
    "Add to {instanceName} " : "Engadir a {instanceName} ",
    "Recently added" : "Engadido recentemente",
    "Most visited" : "Máis visitados",
    "View mode" : "Modo de vista",
    "List view" : "Ver como lista",
    "RSS Feed" : "Fonte RSS",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Retirar permanentemente todos os marcadores da súa conta. Isto non ten volta atrás!",
    "Delete all bookmarks" : "Eliminar todos os marcadores",
    "Open details" : "Abrir detalles",
    "An error occurred while trying to save the bookmark." : "Produciuse un erro ao tentar gardar o marcador.",
    "Error" : "Erro",
    "Uncategorized" : "Sen categorizar",
    "Error parsing the import result" : "Produciuse un erro ao analizar o resultado da importación",
    "Import completed successfully." : "A importación completouse correctamente",
    "Do you really want to delete all your bookmarks?" : "Confirma que quere eliminar todos os seus marcadores?",
    "Set tags" : "Poñer etiquetas",
    "Failed to import one bookmark, because: " : "Produciuse un erro ao importar un marcador por mor de:",
    "No file provided for import" : "Non forneceu ningún ficheiro para importar",
    "Unsupported file type for import" : "Tipo de ficheiro non admitido para importar",
    "A Bookmark manager for Nextcloud" : "Un administrador de marcadores para o Nextcloud",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Este aplicativo permítelle almacenar e organizar os seus lugares favoritos da web nun só lugar, permitíndolle sincronizalos con varios dispositivos e navegadores.\nComprobe os clientes de terceiras partes enumerados aquí: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "Engadir un marcador",
    "This URL is already bookmarked! Overwrite?" : "Este URL xa existe como marcador! Sobrescribilo?",
    "The title of the page" : "O título da páxina",
    "The address of the page" : "O enderezo da páxina",
    "Description of the page" : "Descrición da páxina",
    "Save" : "Gardar",
    "Previews" : "Vistas previas",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "A fin de amosar capturas de pantalla reais doss seus sitios web marcados, o aplicativo Marcadores pode usar un servizo de terceiros para xeralos.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Pode rexistrarse de balde en <a href=\"http://screeenly.com\">screeenly.com</a> ou <a href=\"https://github.com/stefanzweifel/screeenly\">estabelecer o seu propio servidor</a>.",
    "Bookmarks feed" : "Fonte de marcadores"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-bookmarks-1%3a1.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/gl.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcadores",
    "Add a Bookmark" : "Engadir un marcador",
    "Add folder" : "Engadir cartafol",
    "Select" : "Seleccionar",
    "Deselect" : "Deseleccionar",
    "Details" : "Detalles",
    "Delete" : "Eliminar",
    "Saved" : "Gardado",
    "Date added" : "Data na que foi engadido",
    "Link" : "Ligazón",
    "Tags" : "Etiquetas",
    "Description" : "Descrición",
    "No bookmarks here." : "Aquí non hai marcadores. ",
    "Favorites" : "Favoritos",
    "Settings" : "Axustes",
    "Bookmarklet" : "Miniaplicativo ligado",
    "Add to {instanceName} " : "Engadir a {instanceName} ",
    "Recently added" : "Engadido recentemente",
    "Most visited" : "Máis visitados",
    "View mode" : "Modo de vista",
    "List view" : "Ver como lista",
    "RSS Feed" : "Fonte RSS",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Retirar permanentemente todos os marcadores da súa conta. Isto non ten volta atrás!",
    "Delete all bookmarks" : "Eliminar todos os marcadores",
    "Open details" : "Abrir detalles",
    "An error occurred while trying to save the bookmark." : "Produciuse un erro ao tentar gardar o marcador.",
    "Error" : "Erro",
    "Uncategorized" : "Sen categorizar",
    "Error parsing the import result" : "Produciuse un erro ao analizar o resultado da importación",
    "Import completed successfully." : "A importación completouse correctamente",
    "Do you really want to delete all your bookmarks?" : "Confirma que quere eliminar todos os seus marcadores?",
    "Set tags" : "Poñer etiquetas",
    "Not allowed to access folder to import into" : "Non está permitido o acceso ao cartafol para importar cara el",
    "Failed to import one bookmark, because: " : "Produciuse un erro ao importar un marcador por mor de:",
    "No file provided for import" : "Non forneceu ningún ficheiro para importar",
    "Unsupported file type for import" : "Tipo de ficheiro non admitido para importar",
    "A Bookmark manager for Nextcloud" : "Un administrador de marcadores para o Nextcloud",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Este aplicativo permítelle almacenar e organizar os seus lugares favoritos da web nun só lugar, permitíndolle sincronizalos con varios dispositivos e navegadores.\nComprobe os clientes de terceiras partes enumerados aquí: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "Engadir un marcador",
    "This URL is already bookmarked! Overwrite?" : "Este URL xa existe como marcador! Sobrescribilo?",
    "The title of the page" : "O título da páxina",
    "The address of the page" : "O enderezo da páxina",
    "Description of the page" : "Descrición da páxina",
    "Save" : "Gardar",
    "Previews" : "Vistas previas",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "A fin de amosar capturas de pantalla reais doss seus sitios web marcados, o aplicativo Marcadores pode usar un servizo de terceiros para xeralos.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Pode rexistrarse de balde en <a href=\"http://screeenly.com\">screeenly.com</a> ou <a href=\"https://github.com/stefanzweifel/screeenly\">estabelecer o seu propio servidor</a>.",
    "Screeenly API URL" : "URL da API Screeenly",
    "Screeenly API key" : "Chave da API Screeenly",
    "Bookmarks feed" : "Fonte de marcadores"
},
"nplurals=2; plural=(n != 1);");
